summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormorganrOL <morgan.richomme@orange.com>2015-04-28 13:48:55 +0000
committerGerrit Code Review <gerrit@172.30.200.206>2015-04-28 13:48:55 +0000
commit437560f787ea5ac56b59da786f1305d7dbbefa93 (patch)
tree914be7bb8225f6f56c1e0d19188451db8f438ded
parent0714162652ed9a915780ecd46ee85c94b673dbd4 (diff)
parent0c9f6dd8409a3061bec3cc52fe0c997bf83897de (diff)
Merge "Remove hardcoded path, retrieve scenario file dynamically, create results and scenario folder"
-rw-r--r--testcases/VIM/OpenStack/CI/libraries/run_rally.py94
1 files changed, 63 insertions, 31 deletions
diff --git a/testcases/VIM/OpenStack/CI/libraries/run_rally.py b/testcases/VIM/OpenStack/CI/libraries/run_rally.py
index 6ce9b13d8..da5e6adca 100644
--- a/testcases/VIM/OpenStack/CI/libraries/run_rally.py
+++ b/testcases/VIM/OpenStack/CI/libraries/run_rally.py
@@ -1,3 +1,4 @@
+#!/usr/bin/env python
#
# Copyright (c) 2015 Orange
# guyrodrigue.koffi@orange.com
@@ -7,9 +8,8 @@
# which accompanies this distribution, and is available at
# http://www.apache.org/licenses/LICENSE-2.0
#
-#!/usr/bin/python
-import re, json, os, sys
-
+import re, json, os, sys, urllib2
+
def get_task_id(cmd_raw):
"""
get task id from command rally result
@@ -23,7 +23,7 @@ def get_task_id(cmd_raw):
if match:
return match.group(1)
return None
-
+
def task_succeed(json_raw):
"""
Parse JSON from rally JSON results
@@ -36,38 +36,45 @@ def task_succeed(json_raw):
return False
if rally_report.get('result') is None:
return False
-
+
for result in rally_report.get('result'):
if len(result.get('error')) > 0:
return False
-
+
return True
-
-
+
def run_task(test_name):
"""
the "main" function of the script who lunch rally for a task
:param test_name: name for the rally test
:return: void
"""
-
+
""" get the date """
cmd = os.popen("date '+%d%m%Y_%H%M'")
test_date = cmd.read().rstrip()
-
- """ directory for test scenarios files"""
- test_dir = '/home/ubuntu/rally/samples/tasks/scenarios/opnfv'
- test_file_name = "/home/ubuntu/rally/samples/tasks/scenarios/opnfv/opnfv-%s.json" % test_name
- print test_file_name
-
+
+ """ check directory for test scenarios files or retrieve from git otherwise"""
+ tests_path = "./scenarios"
+ test_file_name = '{}/opnfv-{}.json'.format(tests_path, test_name)
+ if not os.path.exists(test_file_name):
+ retrieve_test_cases_file(test_name, tests_path)
+ print "Scenario successfully downloaded"
+
+ print "Start test..."
cmd = os.popen("rally task start --abort-on-sla-failure %s" % test_file_name)
task_id = get_task_id(cmd.read())
-
+
if task_id is None:
print "./run_rally : failed to retrieve task_id"
exit(-1)
-
- report_file_name = "/home/ubuntu/rally/opnfv-%s-%s.html" % (test_name, test_date)
+
+ """ check for result directory and create it otherwise """
+ report_path = "./results"
+ if not os.path.exists(report_path):
+ os.makedirs(report_path)
+
+ report_file_name = '{}/opnfv-{}-{}.html'.format(report_path, test_name, test_date)
os.popen("rally task report %s --out %s" % (task_id, report_file_name))
cmd = os.popen("rally task results %s" % task_id)
@@ -75,30 +82,55 @@ def run_task(test_name):
print "OK"
else:
print "KO"
-
-
+
+
+def retrieve_test_cases_file(test_name, tests_path):
+ """
+ Retrieve from github the sample test files
+ :return: void
+ """
+
+ """ do not add the "/" at the end """
+ url_base = "https://git.opnfv.org/cgit/functest/plain/testcases/VIM/OpenStack/CI/suites"
+
+ test_file_name = 'opnfv-{}.json'.format(test_name)
+ print 'fetching {}/{} ...'.format(url_base, test_file_name)
+ response = urllib2.urlopen('{}/{}'.format(url_base, test_file_name))
+ file_raw = response.read()
+
+ """ check if the test path existe otherwise we create it """
+ if not os.path.exists(tests_path):
+ os.makedirs(tests_path)
+
+ with open('{}/{}'.format(tests_path,test_file_name), 'w') as file:
+ file.write(file_raw)
+
+
def main():
""" configure script """
- tests = ('authenticate','glance','heat','keystone','neutron','nova','tempest','vm', 'all',)
-
-
+ tests = ['authenticate','glance','heat','keystone','neutron','nova','tempest','vm', 'all'];
+
+
if len(sys.argv) != 2:
- print "./run_rally [", tests, "]"
+ options = '{d[0]} | {d[1]} | {d[2]} | {d[3]} | {d[4]} | {d[5]} | {d[6]} | {d[7]} | {d[8]}'.format(d=tests)
+ print "./run_rally [", options, "]"
exit(-1)
test_name = sys.argv[1]
-
+
if not (test_name in tests):
print "argument not valid"
exit(-1)
-
+
if test_name == "all":
- #run test for all tests
- pass
+ for test_name in tests:
+ if not (test_name == 'all' or test_name == 'tempest'):
+ print(test_name)
+ run_task(test_name)
+
else:
run_task(test_name)
-
-
+
+
if __name__ == '__main__':
main()
-